#
# spec file for package python-pyqt-builder
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyqt-builder
Version:        1.17.1
Release:        1.1
Summary:        The PEP 517 compliant PyQt build system
License:        BSD-2-Clause
URL:            https://github.com/Python-PyQt/PyQt-builder
Source0:        https://files.pythonhosted.org/packages/source/P/PyQt-builder/pyqt_builder-%{version}.tar.gz
Source99:       python-pyqt-builder.rpmlintrc
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 64}
# Technically >= 8, but we make it compatible in prep.
BuildRequires:  %{python_module setuptools_scm >= 7}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-packaging
Requires:       python-sip-devel >= 6.7
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       python-PyQt-builder = %{version}-%{release}
BuildArch:      noarch
# SECTION Test Requirements
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module sip-devel >= 6.7}
# /SECTION
%python_subpackages

%description
PyQt-builder is the PEP 517 compliant build system for PyQt and projects that
extend PyQt. It extends the sip build system and uses Qt’s qmake to perform the
actual compilation and installation of extension modules.

Projects that use PyQt-builder provide an appropriate pyproject.toml file and an
optional project.py script. Any PEP 517 compliant frontend, for example
sip-install or pip can then be used to build and install the project.

%prep
%autosetup -p1 -n pyqt_builder-%{version}
# Make it work with setuptools_scm < 8
%if 0%{suse_version} < 1600
sed -i s/version_file/write_to/ pyproject.toml
%endif

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pyqt-bundle
%python_clone -a %{buildroot}%{_bindir}/pyqt-qt-wheel
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONDONTWRITEBYTECODE=1 # boo#1047218
%{python_expand # no real unit tests; check import and bundle entry point
export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python -c 'import pyqtbuild'
%{buildroot}%{_bindir}/pyqt-bundle-%{$python_bin_suffix} -V
}

%post
%python_install_alternative pyqt-bundle pyqt-qt-wheel

%postun
%python_uninstall_alternative pyqt-bundle

%files %{python_files}
%doc README.md LICENSE
%python_alternative %{_bindir}/pyqt-bundle
%python_alternative %{_bindir}/pyqt-qt-wheel
%{python_sitelib}/pyqtbuild
%{python_sitelib}/PyQt_builder-%{version}.dist-info

%changelog
* Wed Jan  8 2025 Ben Greiner <code@bnavigator.de>
- Update to 1.17.1
  * Added support for Qt v6.8
  * Added support for the QtGraphs module.
  * Linux wheels now require GLIBC v2.35 (eg. Ubuntu 22.04) on
    Intel and v2.39 (eg. Ubuntu 24.04) on Arm.
- Drop support-python3.6.patch
  * Python 3.6 is no longer maintained for PyQt
* Mon Nov  4 2024 Daniel Garcia <daniel.garcia@suse.com>
- Use pypi url for source
- Update to 1.16.4
  * Support for Windows on Arm for Qt6
  * Support for Linux on Arm for Qt6
  1.16.3:
  * Link to the stable SIP documentation
  * missing multimedia libraries in Qt v6.7
  * Added support for sub-wheels to pyqt-qt-wheel
  1.16.2:
  * The links to the SIP documentation have been fixed.
  * The ICU libraries were missing from the Linux Qt v6.7 wheels.
* Sun Apr 21 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.16.1
  * The QtQuick3DHelpersImpl, QtQuickControls2MacOSStyleImpl and
    QtQuickTimelineBlendTrees libraries added to Qt v6.7.0 are now
    bundled.
  * The missing `LICENSE` file was added.
* Tue Apr  9 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.16.0
  * The project repository has been migrated to GitHub.
  * PyQt-builder is now licensed under the BSD-2-Clause license.
  * The project has now been migrated from setup.py to
    setuptools_scm and pyproject.toml.
  * The documentation is now hosted at Read the Docs.
  * The QtQuickPhysics libraries added to Qt v6.6.0 are now
    bundled.
  * The QtQuickControls2 style libraries added to Qt v6.6.3 are
    now bundled.
  * The example in the documentation no longer uses deprecated
    features that will be removed in SIP v7.
  * The example is now PyQt6-based rather than PyQt5.
  * The default ABI versions are now v12.13 and v13.6.
* Thu Jan 25 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.15.4
  * Added QtMultimediaQuick to the Qt5 bundle.
  * Removed some plugins from the PyQt5 bundle.
  * Bundle the QtWebChannelQuick library.
* Sun Oct 15 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.15.3
  * Added the '--apple-universal2' command line option to the build
    tools to specify a universal build on macOS.
* Wed Sep 27 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.15.2
  * Bundle the QML libraries for QtCharts and QtDataVisualization
  * Bundle qtscript translations with Qt5 as they are a hidden
    requirement.
  * Bundle the Qt6 qtconnectivity translations.
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Jun  1 2023 Dirk Müller <dmueller@suse.com>
- update to 1.15.1:
  * Added support for bundling the QtLabs QML packages.
* Mon Apr 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.15.0
  * Added support for QtSpatialAudio for PyQt6.
  * A bug fix release.
* Tue Jan 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.14.1
  * Support different patch versions for Qt v5.15.
- Drop pyqt-builder-add-timeline5.15.patch
* Thu Jan 12 2023 Ben Greiner <code@bnavigator.de>
- Add pyqt-builder-add-timeline5.15.patch for Qt3D 5.15.8
* Thu Jan 12 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch to support python 3.6 needed by SLE:
  * support-python3.6.patch
* Mon Oct  3 2022 Ben Greiner <code@bnavigator.de>
- Update to version 1.14.0
  * Added support for QtPdf, QtPdfWidgets and QtTextToSpeech for
    PyQt6.
  * SIP v6.7 is now required.
* Mon Jun 20 2022 Ben Greiner <code@bnavigator.de>
- Update to version 1.13.0
  * The default ABI versions are now v12.11 and v13.4 so that
    wrapped classes can be used by sip.array.
  * Removed support for bundling version of Qt older than v5.15.
  * Removed support for Python v3.6.
* Fri Oct 29 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.12.2
  * Bug fix release related to Apple Silicon and Arm64 Qt wheels
* Sat Oct 16 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.12.1
  * Build universal2 wheels for Qt v6.2 and later when using
    Python v3.10 and later.
  * Added the '--arch' command line option to pyqt-bundle to
    specify a particular architecture (x86_64 or arm64) to
    bundle on macOS.
* Sun Oct  3 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.11.0
  * Added support for bundling Qt v6.2.
  * Added support for PyQt6-WebEngine to pyqt-bundle.
* Thu Aug 19 2021 Ben Greiner <code@bnavigator.de>
- Don't write mtime-based init pyc file during import test
  (boo#1047218)
* Sun Jul  4 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.10.3
  * minor bug fixes for Qt v6.1.2
* Tue Jun 15 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.10.1
  * The default sip module ABI version is now the minimum required
    by current PyQt versions rather than the latest available from
    SIP.
* Thu May 13 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.10.0
  * Added support for bundling Qt v6.1.
  * Added support for PyQt6-Charts to pyqt-bundle.
  * Added support for PyQt6-DataVisualization to pyqt-bundle.
* Thu Mar 11 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.9.1
  * Handle the changed Qt installation directory used by PyQt5
    v5.15.4 and later, and PyQt6 v6.0.3 and later.
* Thu Feb 25 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.9.0
  * Added support for PyQtNetworkAuth.
  * Added support for creating Qt5 wheels.
  * The default minimum glibc version for Qt6 is now v2.28.
* Fri Feb 19 2021 Ben Greiner <code@bnavigator.de>
- Update to version 1.8.0
  * Added the (as yet undocumented) pyqt-qt-wheel utility.
  * chrpath and install_name_tool are no longer required when
    bundling Qt v5.15 or later.
- Changes in v1.7.0
  * Added support for PyQt6, PyQt6-3D and PyQt6-NetworkAuth to
    pyqt-bundle.
* Tue Nov 24 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 1.6.0
  * Appropriate defaults are now provided for the 'abi-version' and
    'sip-module' options.
  * Added the 'jobs' builder option and corresponding '--jobs'
    command line option to sip-build, sip-install and sip-wheel.
- Update License tag
* Sun Aug 30 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 1.5.0
  * Added the 'android-abis' project option and corresponding
    '--android-abi' command line option to sip-build, sip-install
    and sip-wheel.
  * Added 'PYQTBUILD_VERSION' and 'PYQTBUILD_VERSION_STR' to the
    'pyqtbuild' module API.
  * Added support for bundling QtTextToSpeech.
* Sat Aug 29 2020 Benjamin Greiner <code@bnavigator.de>
- Specify noarch
- Provide python-PyQt-builder in case packagers search for the
  official Qt/PyPI name
- It actually needs the python-sip-devel package
* Sat Aug 29 2020 Benjamin Greiner <code@bnavigator.de>
- Initial specfile version 1.4.0
